# Copyright (C) 2009 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""Desktop interface to the Bazaar VCS."""

version_info = (0, 7, 0, 'dev', 0)
__version__ = '.'.join(map(str, version_info))


import sys

import bzrlib
import bzrlib.api
from bzrlib.commands import Command, register_command
from bzrlib.option import Option, RegistryOption

from bzrlib.lazy_import import lazy_import
lazy_import(globals(), '''
from PyQt4 import QtGui, QtCore

from bzrlib.plugins.explorer.lib import explorer
''')


if getattr(sys, "frozen", None):
    # Add our required extra libraries for the standalone bzr.exe to path
    import bzrlib.plugins.qbzr.lib


def load_tests(basic_tests, module, loader):
    from bzrlib.plugins.explorer.tests import load_tests
    return load_tests(basic_tests, module, loader)


def _init_explorer_command(zzz=False, experimental=False):
    # Set up global exception handling.
    from bzrlib.plugins.qbzr.lib.trace import excepthook
    sys.excepthook = excepthook

    try:
        from bzrlib.plugins.qbzr.lib.trace import set_file_bugs_url
        set_file_bugs_url(
                    "https://bugs.launchpad.net/bzr-explorer/+filebug")
    except ImportError:
        # This function is only availible from qbzr 0.13
        pass

    from bzrlib.plugins.explorer.lib import i18n
    if not zzz:
        i18n.install()
    else:
        i18n.install_zzz()
    if experimental:
        from bzrlib.plugins.explorer import lib
        lib.set_experimental_mode(True)


class cmd_explorer(Command):
    """Version Control for Human Beings.

    See http://bazaar-vcs.org/BzrExplorer for an overview of features.

    If a location is given, that location is opened. Otherwise,
    Bazaar Explorer is started with no initial location.
    """

    takes_options = [
        Option("hat", type=str,
            help="Additional set of bookmarks and tools to load.",
            ),
        Option("dry-run",
            help="Start with diagnostic mode enabled.",
            ),
        RegistryOption.from_kwargs("desktop",
            help="Desktop environment to use.",
            gnome="GNOME",
            kde="K Desktop Environment",
            windows="Windows",
            osx="Mac OS X",
            value_switches=True,
            ),
        ]
    if bzrlib.api.get_minimum_api_version(bzrlib) >= (1,14):
        takes_options.extend([
            Option("zzz", hidden=True,
                help="Special zzz translation used for debugging i18n stuff.",
                ),
            Option("experimental", hidden=True,
                help="Enable experimental features.",
                ),
            ])
    takes_args = ['location?']
    aliases = ['explore']

    def run(self, location=None, hat=None, dry_run=False,
            desktop=None, zzz=False, experimental=False):
        _init_explorer_command(zzz, experimental)

        # Start the application
        app = QtGui.QApplication(sys.argv)
        window = explorer.QExplorerMainWindow(location=location, profile=hat,
            desktop=desktop, dry_run=dry_run)
        window.show()
        app.exec_()


register_command(cmd_explorer)
